@@ -170,35 +170,32 @@ class cgfb_smarty
    */
   static public function logout_button($params,&$smarty)
   {
-    if( !self::use_xfbml() )
+    if( !cgfb::uid() ) return;
+
+    $url = cgfb::get_logout_url();
+    $output = '';
+    if( isset($params['urlonly']) )
       {
-	if( !cgfb::uid() ) return;
-
-	$url = cgfb::get_logout_url();
-	$output = '';
-	if( isset($params['urlonly']) )
-	  {
-	    $output = $url;
-	  }
-	else
-	  {
-	    $params['url'] = $url;
-	    if( !isset($params['image']) )
-	      {
-		$params['image'] = self::get_image('fb_logout.gif');
-	      }
-	    $output = cge_tags::link_tag($params);
-	  }
-
-	// handle assign
-	if( isset($params['assign']) )
-	  {
-	    $smarty->assign($params['assign'],$output);
-	    return;
-	  }
-
-	return $output;
+	$output = $url;
       }
+    else
+      {
+	$params['url'] = $url;
+	if( !isset($params['image']) )
+	  {
+	    $params['image'] = self::get_image('fb_logout.gif');
+	  }
+	$output = cge_tags::link_tag($params);
+      }
+
+    // handle assign
+    if( isset($params['assign']) )
+      {
+	$smarty->assign($params['assign'],$output);
+	return;
+      }
+    
+    return $output;
   }
 
 
